==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/statistiques/lang/statistiques_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Odstrániť len prichádzajúce odkazy',
	'bouton_effacer_statistiques' => 'Vymazať všetky štatistiky',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Počet návštev<br />@visites@ návštev',
	'icone_repartition_actuelle' => 'Zobraziť aktuálnu distribúciu',
	'icone_repartition_visites' => 'Rozdelenie návštev',
	'icone_statistiques_visites' => 'Štatistika',
	'info_affichier_visites_articles_plus_visites' => 'Zobraziť návštevy <b>najnavštevovanejších článkov od začiatku:</b>',
	'info_comment_lire_tableau' => 'Ako čítať tento graf',
	'info_forum_statistiques' => 'Štatistika návštev',
	'info_popularite_2' => 'popularita stránky:',
	'info_popularite_3' => 'popularita: @popularite@, návštev: @visites@',
	'info_popularite_5' => 'popularita:',
	'info_previsions' => 'predpovede:',
	'info_question_vignettes_referer' => 'Keď sa pozriete do štatistiky, uvidíte ukážku každej stránky, z ktorej prišiel nejaký návštevník. ',
	'info_question_vignettes_referer_oui' => 'Zobraziť obrázky odkazujúcich stránok',
	'info_visites' => 'Návštev:',
	'info_visites_plus_populaires' => 'Zobraziť návštevy <b>najčítanejších</b> a <b>najnovších publikovaných článkov:</b>',
	'info_zoom' => 'lupa',
	'item_gerer_statistiques' => 'Riadiť štatistiky návštev',

	// O
	'onglet_origine_visites' => 'Pôvod návštev',
	'onglet_repartition_debut' => 'v každom čase',
	'onglet_repartition_lang' => 'Distribúcia podľa jazyka',

	// R
	'resume' => 'Prehľad',

	// T
	'texte_admin_effacer_stats' => 'Tento príkaz vymaže všetky štatistiky o návštevách na stránke, vrátane popularity článkov.',
	'texte_admin_effacer_toutes_stats' => 'Prvé tlačidlo vymaže všetky štatistiky: návštevy, údaje o popularite článkov a prichádzajúcich odkazoch.',
	'texte_comment_lire_tableau' => 'Články sa hodnotia podľa popularity.
 Ak prejdete myšou po názve nejakého článku,
zobrazí sa jeho popularita (tzn. približný počet
 návštev za deň, ktorý bude mať, ak bude pokračovať súčasný trend)
  a počet návštev zaznamenaných odvtedy, čo bol prvýkrát publikovaný.',
	'texte_signification' => 'Tmavé čiary znázorňujú kumulatívne vstupy (celkom za podrubriky), svetlé čiary znázorňujú počet návštev každej rubriky.',
	'titre_evolution_visite' => 'Úroveň návštev',
	'titre_liens_entrants' => 'Prichádzajúce odkazy',
	'titre_page_statistiques' => 'Štatistiky podľa rubrík',
	'titre_page_statistiques_visites' => 'Štatistiky návštev',

	// V
	'visites_journalieres' => 'Počet návštev za deň',
	'visites_mensuelles' => 'Počet návštev za mesiac'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/statistiques/lang/statistiques_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Odstrániť len prichádzajúce odkazy',
	'bouton_effacer_statistiques' => 'Vymazať všetky štatistiky',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Počet návštev<br />@visites@ návštev',
	'icone_repartition_actuelle' => 'Zobraziť aktuálnu distribúciu',
	'icone_repartition_visites' => 'Rozdelenie návštev',
	'icone_statistiques_visites' => 'Štatistiky',
	'info_affichier_visites_articles_plus_visites' => 'V zozname je počet návštev <b>najnavštevovanejších článkov od začiatku:</b>',
	'info_comment_lire_tableau' => 'Ako čítať tento graf',
	'info_forum_statistiques' => 'Štatistiky návštev',
	'info_popularite_2' => 'popularita stránky:',
	'info_popularite_3' => 'popularita: @popularite@, návštev: @visites@',
	'info_popularite_5' => 'popularita:',
	'info_previsions' => 'predpovede:',
	'info_question_vignettes_referer' => 'Keď sa pozriete do štatistiky, uvidíte ukážku každej stránky, z ktorej prišiel nejaký návštevník. ',
	'info_question_vignettes_referer_oui' => 'Zobraziť obrázky odkazujúcich stránok',
	'info_visites' => 'Návštev:',
	'info_visites_plus_populaires' => 'Zoznam  <b>najpopulárnejších</b> a <b>najneskôr publikovaných článkov:</b>',
	'info_zoom' => 'lupa',
	'item_gerer_statistiques' => 'Riadiť štatistiky návštev',

	// O
	'onglet_origine_visites' => 'Pôvod návštev',
	'onglet_repartition_debut' => 'v každom čase',
	'onglet_repartition_lang' => 'Rozdelenie podľa jazykov',

	// R
	'resume' => 'Prehľad',

	// T
	'texte_admin_effacer_stats' => 'Tento príkaz vymaže všetky štatistiky o návštevách na stránke, vrátane popularity článkov.',
	'texte_admin_effacer_toutes_stats' => 'Prvé tlačidlo vymaže všetky štatistiky: návštevy, údaje o popularite článkov a prichádzajúcich odkazoch.',
	'texte_comment_lire_tableau' => 'Články sa hodnotia podľa popularity.
 Ak prejdete myšou po názve nejakého článku,
zobrazí sa jeho popularita (tzn. približný počet
 návštev za deň, ktorý bude mať, ak bude pokračovať súčasný trend)
  a počet návštev zaznamenaných odvtedy, čo bol prvýkrát publikovaný.',
	'texte_signification' => 'Tmavé čiary znázorňujú kumulatívne vstupy (celkom za podrubriky), svetlé čiary znázorňujú počet návštev každej rubriky.',
	'titre_evolution_visite' => 'Vývoj počtu návštev',
	'titre_liens_entrants' => 'Prichádzajúce odkazy',
	'titre_page_statistiques' => 'Štatistiky podľa rubrík',
	'titre_page_statistiques_visites' => 'Štatistiky návštev',

	// V
	'visites_journalieres' => 'Počet návštev za deň',
	'visites_mensuelles' => 'Počet návštev za mesiac'
);

?>
